/*
 * PCX.c
 *
 *  Created on: 27.05.2015
 *      Author: AllanTengg
 */

#include "tc27xc/Ifx_reg.h"
#include <machine/intrinsics.h>
#include <machine/wdtcon.h>
#include <stdlib.h>
#include <string.h>
#include "led.h"
#include "debug.h"
#include "types.h"
#include "TFT.h"

//Display a 256 color PCX image on the given coordiates (x,y)

short int ShowPCX(unsigned short x, unsigned short y, unsigned char *imagedata, unsigned int len)
{
	unsigned char *header;
	unsigned char *p;
	unsigned char *palette;
	unsigned short dimx, dimy;
	unsigned int pixels, n;
	unsigned char lb, c;
	unsigned char i;
	unsigned short line;
	unsigned short col;
	unsigned char r, g, b;

	header = imagedata;
	p = imagedata+128;
	palette = imagedata + len - 256*3;

	//Check image header
	if (header[0] != 0x0a)
	  return -1;

	//Check compression algorithm (only RLE is supported)
	if (header[2] != 0x01)
	  return -2;

    //Check color-depth (only 256 color is supported for now)
	if (header[3] != 8)
	  return -3;

	//Get image size from header
	dimx = (header[8] | (header[9]<<8)) + 1;
	dimy = (header[10] | (header[11]<<8)) + 1;
	pixels = (unsigned)dimy*(unsigned)dimx;

    //Begin decompression of image RLE data
	n = 0;
	line = 0;
    while (n < pixels)
    {
    	//Look if we have a length byte
    	if (((*p) & 0xc0) == 0xc0)
    	{
    		//Extract the length from the length byte (6bit)
    		lb = (*p) & 0x3f;
    		p++;

    		//After the length follows the color index byte
    		c = *p;
    		p++;

    		//Look up the color in the palette
    		r = palette[c*3+0];
    		g = palette[c*3+1];
    		b = palette[c*3+2];
    		col = RGB(r,g,b);

    		//Finally output lb pixels in the line buffer
    		for (i=0; i<lb; i++)
    		{
    			Pixel_Buff[line] = col;
    			n++;
    			line++;

    			//Check if the line is complete
        		if (line == dimx)
        		{
        			line = 0;
        			TFT_SetXY (x, y); y--;
        			TFT_Flush_Row_Buff(dimx);
        		}
    		}

    	}
    	else
    	//otherwise it is directly a pixel byte
    	{
    		//The value represents the color
    		c = *p;
    		p++;

    		//Look up the color in the palette
    		r = palette[c*3+0];
    		g = palette[c*3+1];
    		b = palette[c*3+2];
    		col = RGB(r,g,b);

    		//Put the color pixel in the line buffer
			Pixel_Buff[line] = col;
    		n++;
    		line++;

    		//Check if the line is complete
    		if (line == dimx)
    		{
    			line = 0;
    			TFT_SetXY (x, y); y--;
    			TFT_Flush_Row_Buff(dimx);
    		}
    	}
    }

	return 0;
}
