
#include <stdio.h>
#include "FreeRTOS.h"
#include "queue.h"
#include "types.h"
#include "string.h"
#include "lwip/opt.h"
#include "lwip/arch.h"
#include "lwip/api.h"
#include "lwip/inet.h"
#include "lwip/sockets.h"
#include "httpserver-socket.h"
#include "task.h"
#include "fs.h"
#include "fsdata.h"

u32_t nPageHits = 0;
portCHAR PAGE_BODY[512];

/* Format of dynamic web page: the page header */

static const char PAGE_START[] =
{
"<!DOCTYPE html PUBLIC \"-//W3C//DTD HTML 4.01//EN\" \"http://www.w3.org/TR/html4/strict.dtd\">"
"<html><head><meta http-equiv=\"Content-Type\" content=\"text/html; charset=windows-1252\">"
"<title> TC27xT FreeRTOS </title>"
"<meta http-equiv=\"refresh\" content=\"1\">"
"<meta content=\"MSHTML 6.00.2800.1561\" name=\"GENERATOR\">"
"<style =\"font-weight:=\"\" normal;=\"\" font-family:=\"\" verdana;\"=\"\"></style>"
"</head>"
"<body>"
"<h4><small style=\"font-family: Verdana;\"><small><big><big><big style=\"font-weight: bold;\"><big><strong><em><span style=\"font-style: italic;\">Aurix TC277 List of tasks and their status</span></em></strong></big></big></big></big></small></small></h4>"
"<hr style=\"width: 100%; height: 2px;\"><span style=\"font-weight: bold;\">"
"</span><span style=\"font-weight: bold;\">"
"<table style=\"width: 961px; height: 30px;\" border=\"1\" cellpadding=\"2\" cellspacing=\"2\">"
"<tbody>"
"    <tr>"
"      <td style=\"font-family: Verdana; font-weight: bold; font-style: italic; background-color: rgb(0, 70, 107); text-align: center;\"><small><a href=\"aurixrtos.html\"><span style=\"color: white;\">Homepage</span></a></small></td>"
"      <td style=\"font-family: Verdana; font-weight: bold; font-style: italic; background-color: rgb(0, 70, 107); text-align: center;\"><a href=\"freertos.html\"><span style=\"font-weight: bold;\"></span></a><small><a href=\"freertos.html\"><span style=\"color: white;\">List"
"of tasks</span></a></small></td>"
"    </tr>"
"  </tbody>"
"</table>"
"<br>"
"</span><span style=\"font-weight: bold;\"></span><small><span style=\"font-family: Verdana;\">Number of page hits: "
"\0"
};


/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/**
  * @brief serve tcp connection  
  * @param conn: connection socket 
  * @retval None
  */
void http_server_serve(int conn) 
{
  int buflen = 1500;
  int ret;
  struct fs_file * file;
  unsigned char recv_buffer[1500];
  unsigned short intval;
				
  memset(recv_buffer,0, 1500);

  /* Read in the request */
  ret = read(conn, recv_buffer, buflen); 
  if(ret < 0) return;

  /* Check if request to get viflogo.gif */
  if (strncmp((char *)recv_buffer,"GET /viflogo.gif", 16)==0)
  {
    file = fs_open("/viflogo.gif");
    write(conn, (const unsigned char*)(file->data), (size_t)file->len);
    if(file) fs_close(file);
  }
  /* Check if request to get aurix.jpg */
  else if (strncmp((char *)recv_buffer,"GET /freertos.jpg", 17)==0)
  {
    file = fs_open("/freertos.jpg");
    write(conn, (const unsigned char*)(file->data), (size_t)file->len);
    if(file) fs_close(file);
  }
  /* Check if request to get infineon.png */
  else if (strncmp((char *)recv_buffer,"GET /error.png", 14) == 0)
  {
    file = fs_open("/error.png");
    write(conn, (const unsigned char*)(file->data), (size_t)file->len);
    if(file) fs_close(file);
  }
  else if(strncmp((char *)recv_buffer, "GET /freertos.html", 18) == 0)
  {
    /* Load dynamic page */
    DynWebPage(conn);
  }
  else if((strncmp((char *)recv_buffer, "GET /aurixrtos.htm", 18) == 0)||(strncmp((char *)recv_buffer, "GET / ", 6) == 0))
  {
    /* Load STM32F2x7 page */
    file = fs_open("/aurixrtos.htm");
    write(conn, (const unsigned char*)(file->data), (size_t)file->len);
    if(file) fs_close(file);
  }
  else
  {
    /* Load 404 page */
    file = fs_open("/notfound.html");
    write(conn, (const unsigned char*)(file->data), (size_t)file->len);
    if(file) fs_close(file);
  }
  /* Close connection socket */
  close(conn);
}

/**
  * @brief  http server thread
  * @param arg: pointer on argument(not used here)
  * @retval None
  */
void http_server_socket_thread(void *arg)
{
  int sock, newconn, size;
  struct sockaddr_in address, remotehost;

 /* create a TCP socket */
  if ((sock = socket(AF_INET, SOCK_STREAM, 0)) < 0)
  {
    //printf("can not create socket");
    return;
  }

  /* bind to port 80 at any interface */
  address.sin_family = AF_INET;
  address.sin_port = htons(80);
  address.sin_addr.s_addr = INADDR_ANY;

  if (bind(sock, (struct sockaddr *)&address, sizeof (address)) < 0)
  {
    //printf("can not bind socket");
    return;
  }

  /* listen for incoming connections (TCP listen backlog = 5) */
  listen(sock, 5);

  size = sizeof(remotehost);

  while (1)
  {
    newconn = accept(sock, (struct sockaddr *)&remotehost, (socklen_t *)&size);
    http_server_serve(newconn);
  }
}

/**
  * @brief  Initialize the HTTP server (start its thread)
  * @param  none
  * @retval None
  */
void http_server_socket_init()
{
  sys_thread_new("HTTP", http_server_socket_thread, NULL, DEFAULT_THREAD_STACKSIZE * 2, WEBSERVER_THREAD_PRIO);
}



/**
  * @brief  Create and send a dynamic Web Page. This page contains the list of 
  *         running tasks and the number of page hits. 
  * @param  conn connection socket
  * @retval None
  */
void DynWebPage(int conn)
{
  portCHAR pagehits[32];

  memset(PAGE_BODY, 0,512);

  /* Update the hit count */
  nPageHits++;
  sprintf( pagehits, "%d (%d)", nPageHits, conn);
  strcat(PAGE_BODY, pagehits);
  strcat((char *) PAGE_BODY, "<pre><br>Name          State  Priority  Stack   Num" );
  strcat((char *) PAGE_BODY, "<br>---------------------------------------------<br>"); 
    
  /* The list of tasks and their status */
  vTaskList((signed char *)(PAGE_BODY + strlen(PAGE_BODY)));
  strcat((char *) PAGE_BODY, "<br><br>---------------------------------------------"); 
  strcat((char *) PAGE_BODY, "<br>B : Blocked, R : Ready, D : Deleted, S : Suspended<br>");
  
  /* Send the dynamically generated page */
  write(conn, PAGE_START, strlen((char*)PAGE_START));
  write(conn, PAGE_BODY, strlen(PAGE_BODY));
}

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
