/*====================================================================
* Project:  EMC2 Demo example for Aurix/Oikos board including
*
*           - System setup
*           - PLL configuration
*           - LED / I/O port operation
*           - System timer
*
*====================================================================*/

#include "tc27xc/Ifx_reg.h"
#include <machine/intrinsics.h>
#include "system_tc2x.h"
#include "interrupts.h"
#include "cpufreq.h"
#include "led.h"
#include "debug.h"
#include "timer.h"
#include <stdlib.h>
#include <string.h>
#include <machine/wdtcon.h>
#include "FreeRTOS.h"
#include "task.h"
#include "led.h"
#include "httpserver-socket.h"
#include "TLF35584.h"
#include "ethernetif.h"
#include "IfxEth_Phy_Pef7071.h"
#include "TFT.h"
#include "sharedmem.h"

#define HEARTBEAT_TASK_PRIORITY 3
#define INTERCORE_TASK_PRIORITY 4

void vLEDHeartbeatTask (void *pvParameters )
{
   unsigned long xLastFlashTime;
   unsigned xFlashRate = 200;

	// Calculate the LED and flash rate.
	portENTER_CRITICAL();
	{
		//...
	}
	portEXIT_CRITICAL();

	// We need to initialise xLastFlashTime prior to the first call to vTaskDelayUntil().
	xLastFlashTime = xTaskGetTickCount();

	for(;;)
	{
		// Delay for half the flash period then turn the LED on.
		ToggleLED(3);
		vTaskDelayUntil( &xLastFlashTime, xFlashRate );
	}
}

void vSharedMemTestTask (void *pvParameters )
{
	unsigned int incdata[4];
	short int n;

	for(;;)
	{
		n = SharedMemReceive(incdata, 1, 0xffffff);
		if (n > 0)
		{
			ToggleLED(2);
		}
	}
}


void main0( void )
{
	// Enable interrupts globally
	_enable();

	// First create the led-blink
	xTaskCreate( vLEDHeartbeatTask, "LED", 128, NULL, HEARTBEAT_TASK_PRIORITY,  NULL );

	//Then create a task to test inter core communication
	xTaskCreate( vSharedMemTestTask, "ICC", 128, NULL, INTERCORE_TASK_PRIORITY,  NULL );

	// Start the scheduler
	vTaskStartScheduler();

	// The following line should never be reached.
	while(1);
}
