/*====================================================================
* Project:  EMC2 Demo example for Aurix/Oikos board including
*
*           - System setup
*           - PLL configuration
*           - LED / I/O port operation
*           - System timer
*
*====================================================================*/

#include "tc27xc/Ifx_reg.h"
#include <machine/intrinsics.h>
#include "system_tc2x.h"
#include "interrupts.h"
#include "cpufreq.h"
#include "led.h"
#include "debug.h"
#include "timer.h"
#include <stdlib.h>
#include <string.h>
#include <machine/wdtcon.h>
#include "FreeRTOS.h"
#include "task.h"
#include "led.h"
#include "httpserver-socket.h"
#include "TLF35584.h"
#include "ethernetif.h"
#include "IfxEth_Phy_Pef7071.h"
#include "sharedmem.h"

//Priorities for the demo application tasks.
#define LED_TASK_PRIORITY		( tskIDLE_PRIORITY + 3 )

const unsigned char MAC_ADDRESS[6] = {0xca, 0xfe, 0x00, 0x00, 0x00, 0x01};
const unsigned char IP_ADDRESS[4] = {192,168,0,100};
const unsigned char NET_MASK[4] = {255,255,255,0};
const unsigned char DEF_GATEWAY[4] = {192,168,0,1};
const unsigned int socknums[] = {0,1};

extern void LwIP_Init(void);
extern void http_server_socket_init();

unsigned char eth_link;

void vLEDFlashTask (void *pvParameters )
{
   unsigned long xLastFlashTime;
   unsigned xFlashRate=200;
   unsigned int count = 0;

	// Calculate the LED and flash rate.
	portENTER_CRITICAL();
	{
		//...
	}
	portEXIT_CRITICAL();

	// We need to initialise xLastFlashTime prior to the first call to vTaskDelayUntil().
	xLastFlashTime = xTaskGetTickCount();

	for(;;)
	{
		// Delay for half the flash period then turn the LED on.
		ToggleLED(0);
		eth_link = IfxEth_Phy_Pef7071_link();

		count++;
		if ((count & 7) == 7)
		{
			SharedMemSend(0, &count, 1);
		}

		vTaskDelayUntil( &xLastFlashTime, xFlashRate );
	}
}

void main1( void )
{
	uint16 i;

	// Configure Ethernet and PHY device
	ETH_Init();

	// Now start the TCP/IP stack
	LwIP_Init();

	// Enable interrupts globally
	_enable();

	// First create the led-blink
	xTaskCreate( vLEDFlashTask, "LED", 128, NULL, LED_TASK_PRIORITY,  NULL );

    // Initialize Webserver Demo
    http_server_socket_init();

	// Start the scheduler
	vTaskStartScheduler();

	// The following line should never be reached.
	while(1);
}
